Nrml

Struct Nrml 

pub struct Nrml<const N: usize, S: Field>(/* private fields */);

Implementations

Source

impl<S: Field, const N: usize> Nrml<N, S>

pub const unsafe fn new_unchecked(array: [S; N]) -> Nrml<N, S>

.

Safety

This is safe if the values are actually normalized.

They should have just been divided by their magnitude.

.

pub const fn axis(i: usize) -> Self

Source

impl<const N: usize> Nrml<N, f32>

pub fn to_f64(self) -> Nrml<N, f64>

Source

impl<const N: usize> Nrml<N, f64>

pub fn to_f32(self) -> Nrml<N, f32>

Source

impl<S: Field, const N: usize> Nrml<N, S>

pub fn array(self) -> [S; N]

Source

impl<S: Field> Nrml<1, S>

pub fn x(self) -> S

Source

impl<S: Field> Nrml<2, S>

pub fn x(self) -> S

pub fn y(self) -> S

Source

impl<S: Field> Nrml<3, S>

pub fn x(self) -> S

pub fn y(self) -> S

pub fn z(self) -> S

Source

impl<S: Field> Nrml<4, S>

pub fn x(self) -> S

pub fn y(self) -> S

pub fn z(self) -> S

pub fn w(self) -> S